@@ -17,7 +17,10 @@ class DigitalOcean(BaseCloud):
 
     def get_ssh_key_id(self):
         """Return uploaded key id if this SSH public key has been already
-        submitted to the cloud provider. None otherwise."""
+        submitted to Digital Ocean. We use libcloud's 
+        `driver.ex_list_ssh_keys` in order to find it out. 
+
+        Return None if the SSH key still has to be uploaded."""
         uploaded_key = [ key.id for key in self.driver.ex_list_ssh_keys() 
             if key.name == self.ssh_key_name ]
 
@@ -25,6 +28,12 @@ class DigitalOcean(BaseCloud):
             return str(uploaded_key[0])
         
     def deploy(self, image_id, size_idx=0, location_idx=0, name='test'):
+        """Digital Ocean needs the following information: VM size, image, name,
+        location and SSH key id.
+        
+        First, we check if our SSH key is already uploaded on Digital Ocean's
+        cloud. If not, we upload it using libcloud's `driver.ex_create_ssh_key`. 
+        Then, we call `self.startup` with the required arguments."""
         key_id = self.get_ssh_key_id()
 
         if not key_id:
@@ -43,4 +52,3 @@ class DigitalOcean(BaseCloud):
             'size': size, 'image': Image, 'name': name,
             'location': location, 'ex_ssh_key_ids': [ key_id ]
         })
-
